<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
if ( ! class_exists( 'Coupon_Pro_Generate_Bulk_Coupons' ) ) {
	/**
	 * Class for Bulk Generate Coupons
	 */
	class Coupon_Pro_Generate_Bulk_Coupons {
		public function __construct() {
			add_action( 'admin_enqueue_scripts', array( $this, 'sc_bulk_generate_coupon_styles_and_scripts' ) );
			add_action( 'admin_menu', array( $this, 'coupon_pro_bulk_generate_menu') );
			add_action( 'admin_init', array( $this, 'coupon_pro_bulk_generate_post_data' ) );	
			add_action( 'woocommerce_coupon_options', array($this, 'woocommerce_smart_coupon_options')); 
			add_action( 'save_post_shop_coupon', array($this, 'woocommerce_process_smart_coupon_meta'), 19, 2 );		
		}
		public function sc_bulk_generate_coupon_styles_and_scripts(){
			global $pagenow, $wp_scripts;
			if ( empty( $pagenow ) || $pagenow != 'admin.php' ) { 
				return;
			}
			if ( empty( $_GET['page'] ) || $_GET['page'] != 'coupon_pro_generate_bulk' ) { 
				return;
			}
			$suffix         = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
			$jquery_version = isset( $wp_scripts->registered['jquery-ui-core']->ver ) ? $wp_scripts->registered['jquery-ui-core']->ver : '1.9.2';
			$locale  = localeconv();
			$decimal = isset( $locale['decimal_point'] ) ? $locale['decimal_point'] : '.';
			$woocommerce_admin_params = array(
				'i18n_decimal_error'                => sprintf( __( 'Please enter in decimal (%s) format without thousand separators.', 'COUPON_PRO_TXT_DMN' ), $decimal ),
				'i18n_mon_decimal_error'            => sprintf( __( 'Please enter in monetary decimal (%s) format without thousand separators and currency symbols.', 'COUPON_PRO_TXT_DMN' ), wc_get_price_decimal_separator() ),
				'i18n_country_iso_error'            => __( 'Please enter in country code with two capital letters.', 'COUPON_PRO_TXT_DMN' ),
				'i18_sale_less_than_regular_error'  => __( 'Please enter in a value less than the regular price.', 'COUPON_PRO_TXT_DMN' ),
				'decimal_point'                     => $decimal,
				'mon_decimal_point'                 => wc_get_price_decimal_separator(),
				'strings' => array(
					'import_products' => __( 'Import', 'COUPON_PRO_TXT_DMN' ),
					'export_products' => __( 'Export', 'COUPON_PRO_TXT_DMN' ),
				),
				'urls' => array(
					'import_products' => esc_url_raw( admin_url( 'edit.php?post_type=product&page=product_importer' ) ),
					'export_products' => esc_url_raw( admin_url( 'edit.php?post_type=product&page=product_exporter' ) ),
				),
			);
			$woocommerce_admin_meta_boxes_params = array(
				'remove_item_notice'            => __( 'Are you sure you want to remove the selected items? If you have previously reduced this item\'s stock, or this order was submitted by a customer, you will need to manually restore the item\'s stock.', 'COUPON_PRO_TXT_DMN' ),
				'i18n_select_items'             => __( 'Please select some items.', 'COUPON_PRO_TXT_DMN' ),
				'i18n_do_refund'                => __( 'Are you sure you wish to process this refund? This action cannot be undone.', 'COUPON_PRO_TXT_DMN' ),
				'i18n_delete_refund'            => __( 'Are you sure you wish to delete this refund? This action cannot be undone.', 'COUPON_PRO_TXT_DMN' ),
				'i18n_delete_tax'               => __( 'Are you sure you wish to delete this tax column? This action cannot be undone.', 'COUPON_PRO_TXT_DMN' ),
				'remove_item_meta'              => __( 'Remove this item meta?', 'COUPON_PRO_TXT_DMN' ),
				'remove_attribute'              => __( 'Remove this attribute?', 'COUPON_PRO_TXT_DMN' ),
				'name_label'                    => __( 'Name', 'COUPON_PRO_TXT_DMN' ),
				'remove_label'                  => __( 'Remove', 'COUPON_PRO_TXT_DMN' ),
				'click_to_toggle'               => __( 'Click to toggle', 'COUPON_PRO_TXT_DMN' ),
				'values_label'                  => __( 'Value(s)', 'COUPON_PRO_TXT_DMN' ),
				'text_attribute_tip'            => __( 'Enter some text, or some attributes by pipe (|) separating values.', 'COUPON_PRO_TXT_DMN' ),
				'visible_label'                 => __( 'Visible on the product page', 'COUPON_PRO_TXT_DMN' ),
				'used_for_variations_label'     => __( 'Used for variations', 'COUPON_PRO_TXT_DMN' ),
				'new_attribute_prompt'          => __( 'Enter a name for the new attribute term:', 'COUPON_PRO_TXT_DMN' ),
				'calc_totals'                   => __( 'Calculate totals based on order items, discounts, and shipping?', 'COUPON_PRO_TXT_DMN' ),
				'calc_line_taxes'               => __( 'Calculate line taxes? This will calculate taxes based on the customers country. If no billing/shipping is set it will use the store base country.', 'COUPON_PRO_TXT_DMN' ),
				'copy_billing'                  => __( 'Copy billing information to shipping information? This will remove any currently entered shipping information.', 'COUPON_PRO_TXT_DMN' ),
				'load_billing'                  => __( 'Load the customer\'s billing information? This will remove any currently entered billing information.', 'COUPON_PRO_TXT_DMN' ),
				'load_shipping'                 => __( 'Load the customer\'s shipping information? This will remove any currently entered shipping information.', 'COUPON_PRO_TXT_DMN' ),
				'featured_label'                => __( 'Featured', 'COUPON_PRO_TXT_DMN' ),
				'prices_include_tax'            => esc_attr( get_option( 'woocommerce_prices_include_tax' ) ),
				'round_at_subtotal'             => esc_attr( get_option( 'woocommerce_tax_round_at_subtotal' ) ),
				'no_customer_selected'          => __( 'No customer selected', 'COUPON_PRO_TXT_DMN' ),
				'plugin_url'                    => WC()->plugin_url(),
				'ajax_url'                      => admin_url( 'admin-ajax.php' ),
				'order_item_nonce'              => wp_create_nonce( 'order-item' ),
				'add_attribute_nonce'           => wp_create_nonce( 'add-attribute' ),
				'save_attributes_nonce'         => wp_create_nonce( 'save-attributes' ),
				'calc_totals_nonce'             => wp_create_nonce( 'calc-totals' ),
				'get_customer_details_nonce'    => wp_create_nonce( 'get-customer-details' ),
				'search_products_nonce'         => wp_create_nonce( 'search-products' ),
				'grant_access_nonce'            => wp_create_nonce( 'grant-access' ),
				'revoke_access_nonce'           => wp_create_nonce( 'revoke-access' ),
				'add_order_note_nonce'          => wp_create_nonce( 'add-order-note' ),
				'delete_order_note_nonce'       => wp_create_nonce( 'delete-order-note' ),
				'calendar_image'                => WC()->plugin_url() . '/assets/images/calendar.png',
				'post_id'                       => '',
				'base_country'                  => WC()->countries->get_base_country(),
				'currency_format_num_decimals'  => wc_get_price_decimals(),
				'currency_format_symbol'        => get_woocommerce_currency_symbol(),
				'currency_format_decimal_sep'   => esc_attr( wc_get_price_decimal_separator() ),
				'currency_format_thousand_sep'  => esc_attr( wc_get_price_thousand_separator() ),
				'currency_format'               => esc_attr( str_replace( array( '%1$s', '%2$s' ), array( '%s', '%v' ), get_woocommerce_price_format() ) ), // For accounting JS
				'rounding_precision'            => WC_ROUNDING_PRECISION,
				'tax_rounding_mode'             => WC_TAX_ROUNDING_MODE,
				'product_types'                 => array_map( 'sanitize_title', get_terms( 'product_type', array( 'hide_empty' => false, 'fields' => 'names' ) ) ),
				'i18n_download_permission_fail' => __( 'Could not grant access - the user may already have permission for this file or billing email is not set. Ensure the billing email is set, and the order has been saved.', 'COUPON_PRO_TXT_DMN' ),
				'i18n_permission_revoke'        => __( 'Are you sure you want to revoke access to this download?', 'COUPON_PRO_TXT_DMN' ),
				'i18n_tax_rate_already_exists'  => __( 'You cannot add the same tax rate twice!', 'COUPON_PRO_TXT_DMN' ),
				'i18n_product_type_alert'       => __( 'Your product has variations! Before changing the product type, it is a good idea to delete the variations to avoid errors in the stock reports.', 'COUPON_PRO_TXT_DMN' ),
			);
			wp_enqueue_style( 'woocommerce_admin_menu_styles', WC()->plugin_url() . '/assets/css/menu.css', array(), WC()->version );
			wp_enqueue_style( 'woocommerce_admin_styles', WC()->plugin_url() . '/assets/css/admin.css', array(), WC()->version );
			wp_enqueue_style( 'jquery-ui-style', '//code.jquery.com/ui/' . $jquery_version . '/themes/smoothness/jquery-ui.css', array(), $jquery_version );
			wp_enqueue_script( 'wc-admin-coupon-meta-boxes', WC()->plugin_url() . '/assets/js/admin/meta-boxes-coupon' . $suffix . '.js', array( 'woocommerce_admin', 'wc-enhanced-select', 'wc-admin-meta-boxes' ), WC()->version );
			wp_localize_script( 'wc-admin-meta-boxes', 'woocommerce_admin_meta_boxes', $woocommerce_admin_meta_boxes_params );
			wp_enqueue_script( 'woocommerce_admin', WC()->plugin_url() . '/assets/js/admin/woocommerce_admin' . $suffix . '.js', array( 'jquery', 'jquery-blockui', 'jquery-ui-sortable', 'jquery-ui-widget', 'jquery-ui-core', 'jquery-tiptip' ), WC()->version );
			wp_localize_script( 'woocommerce_admin', 'woocommerce_admin', $woocommerce_admin_params );
		}
		public function coupon_pro_bulk_generate_menu() {
			add_submenu_page(
								'woocommerce',
								__('Generate Bulk Coupons','COUPON_PRO_TXT_DMN'),
								__('Generate Bulk Coupons','COUPON_PRO_TXT_DMN'),
								'edit_pages', 'coupon_pro_generate_bulk',
								array($this , 'func_coupon_pro_generate_bulk' )
							);
		}
		public function coupon_pro_bulk_generate_post_data() {
			if ( isset( $_GET['action'] ) && !empty( $_GET['action'] ) && ( $_GET['action'] == 'generate_coupons' ) ) {
				if(isset($_POST['smart_coupons_generate_action']) ) {
					if($_POST['smart_coupons_generate_action'] == 'add_to_store') {
						$this->add_to_store_coupon_generate_action($_POST);
					} else if ($_POST['smart_coupons_generate_action'] == 'export_smart_coupon') {
						$this->export_smart_coupon_coupon_generate_action($_POST);
					} else if ($_POST['smart_coupons_generate_action'] == 'smart_coupon_email_coupons') {
						$this->smart_coupon_email_coupons_coupon_generate_action($_POST);
					}
				}
			}
		}
		public function add_to_store_coupon_generate_action($data) {
			if(isset($data['no_of_coupons_to_generate']) && !empty($data['no_of_coupons_to_generate'])) {
				$total_coupons = $data['no_of_coupons_to_generate'];
				$coupons_prefix = trim($data['bulk_generate_coupons_prefix']);
				$coupons_suffix = trim($data['bulk_generate_coupons_suffix']);
				for ($i=0; $i < $total_coupons; $i++) { 
					$coupons_title = Coupon_Pro_Send_Email::RandomString();
					$coupons_add = array(
											'post_title' => trim($coupons_prefix.$coupons_title.$coupons_suffix), 
											'post_excerpt' => "", 
											'post_status' => 'publish', 
											'menu_order' => 0,											
										);
					$add_coupon_array = array_merge($coupons_add, $data);					
					Coupon_Pro_Import_Export_Coupons::import_coupon($add_coupon_array);
				}
			}
		}
		public function export_smart_coupon_coupon_generate_action($data) {
			if(isset($data['no_of_coupons_to_generate']) && !empty($data['no_of_coupons_to_generate'])) {
				$total_coupons = $data['no_of_coupons_to_generate'];
				$coupons_prefix = trim($data['bulk_generate_coupons_prefix']);
				$coupons_suffix = trim($data['bulk_generate_coupons_suffix']);
				$export_coupons  = array();
				for ($i=0; $i < $total_coupons; $i++) { 
						$coupons_title = Coupon_Pro_Send_Email::RandomString();
						if(isset( $data['product_ids'] ) && is_array( $data['product_ids'] ))
							$product_ids = implode(",",$data['product_ids']);
						else
							$product_ids = isset($data['product_ids']);
						if(isset( $data['exclude_product_ids'] ) && is_array( $data['exclude_product_ids'] ))
							$exclude_product_ids = implode(",",$data['exclude_product_ids']);
						else
							$exclude_product_ids = isset($data['exclude_product_ids']);
						if(isset( $data['product_categories'] ) && is_array( $data['product_categories'] ))
							$product_categories = implode(",",$data['product_categories']);
						else
							$product_categories = isset($data['product_categories']);
						if(isset( $data['exclude_product_categories'] ) && is_array( $data['exclude_product_categories'] ))
							$exclude_product_categories = implode(",",$data['exclude_product_categories']);
						else
							$exclude_product_categories = isset( $data['exclude_product_categories']);
						$export_coupons[] = array(
												'post_title' => $coupons_prefix.$coupons_title.$coupons_suffix, 
												'discount_type' => isset($data['discount_type']) ? trim($data['discount_type']) : NULL ,
												'coupon_amount' => isset($data['coupon_amount']) ? $data['coupon_amount'] : "", 
												'free_shipping' => isset($data['free_shipping'])? $data['free_shipping'] : "", 
												'expiry_date'   => isset($data['expiry_date']) ? $data['expiry_date'] : "", 
												'minimum_amount' => isset($data['minimum_amount']) ? $data['minimum_amount'] : "", 
												'maximum_amount' => isset($data['maximum_amount']) ? $data['maximum_amount'] : "", 
												'individual_use'   => isset($data['individual_use']) ? $data['individual_use'] : "", 
												'exclude_sale_items'  => isset($data['exclude_sale_items']) ? $data['exclude_sale_items'] : "", 
												'product_ids'  => $product_ids,
												'exclude_product_ids'  => $exclude_product_ids,
												'product_categories'  => $product_categories,
												'exclude_product_categories' => $exclude_product_categories,
												'customer_email'  => isset($data['customer_email']) ? $data['customer_email'] : "", 	
												'usage_limit'  => isset($data['usage_limit']) ? $data['usage_limit'] : "", 
												'usage_limit_per_user'  => isset($data['usage_limit_per_user'])? $data['usage_limit_per_user'] : "",
												'smart_coupon_visible_on_my_account' => isset($data['smart_coupon_visible_on_my_account'])? $data['smart_coupon_visible_on_my_account'] : "no",
												'smart_coupon_visible_on_cart' => isset($data['smart_coupon_visible_on_cart'])? $data['smart_coupon_visible_on_cart'] : "no",
												'limit_usage_to_x_item' => isset($data['limit_usage_to_x_item'])? $data['limit_usage_to_x_item'] : ""
											);
				}
				$this->export_to_csv($export_coupons);
				die();
			}		
		}
		public function smart_coupon_email_coupons_coupon_generate_action($data) {
			if(isset($data['no_of_coupons_to_generate']) && !empty($data['no_of_coupons_to_generate'])) {
				$total_coupons = $data['no_of_coupons_to_generate'];
				$coupons_prefix = trim($data['bulk_generate_coupons_prefix']);
				$coupons_suffix = trim($data['bulk_generate_coupons_suffix']);
				for ($i=0; $i < $total_coupons; $i++) { 
					$coupons_title = Coupon_Pro_Send_Email::RandomString();
					$coupons_add = array(
											'post_title' => trim($coupons_prefix.$coupons_title.$coupons_suffix), 
											'post_excerpt' => "", 
											'post_status' => 'publish', 
											'menu_order' => 0,											
										);
					$add_coupon_array = array_merge($coupons_add, $data);					
					Coupon_Pro_Import_Export_Coupons::import_coupon($add_coupon_array);
				}
			}
		}
		public function func_coupon_pro_generate_bulk() {
			global $post;
			global $woocommerce;
			$empty_reference_coupon = get_option( 'empty_reference_smart_coupons' );
			if ( $empty_reference_coupon === false ) {
				$args = array(
							'post_status' => 'auto-draft',
							'post_type' => 'shop_coupon',
						);
				$reference_post_id = wp_insert_post( $args );
				update_option( 'empty_reference_smart_coupons', $reference_post_id );
			} else {
				$reference_post_id = $empty_reference_coupon;
			}
			$post = get_post( $reference_post_id );
			if ( empty( $post ) ) {
				$args = array(
							'post_status' => 'auto-draft',
							'post_type' => 'shop_coupon',
						);
				$reference_post_id = wp_insert_post( $args );
				update_option( 'empty_reference_smart_coupons', $reference_post_id );
				$post = get_post( $reference_post_id );
			}
			?>
			<h2>
				<?php echo __( 'Coupon Pro', 'COUPON_PRO_TXT_DMN' ); ?>
				<a href="<?php echo trailingslashit( admin_url() ) . 'post-new.php?post_type=shop_coupon'; ?>" class="page-title-action"><?php echo __( 'Add Coupon', 'COUPON_PRO_TXT_DMN' ); ?></a>
			</h2>
			<?php 
			Coupon_Pro_Settings_Helper::tabs();
			?>
			<div id="message"><p></p></div>
			<div class="tool-box">
				<p class="description"><?php _e( 'Generate Bulk Coupon', 'COUPON_PRO_TXT_DMN' ); ?></p>
				<style type="text/css">
					.coupon_actions {
						margin-left: 14px;
					}
					#smart-coupon-action-panel p label {
						width: 30%;
					}
					#smart-coupon-action-panel {
						width: 100% !important;
					}
					.sc-required-mark {
						color: red;
					}
					.coupon_data_tabs {
						display: block !important;
					}
				</style>
				<form id="generate_coupons" action="<?php echo add_query_arg( array( 'page' => 'coupon_pro_generate_bulk', 'action' => 'generate_coupons' ), admin_url( 'admin.php' ) ); ?>" method="post">					
					<?php wp_nonce_field( 'sc-bulk-generate-coupon' ); ?>
					<div id="poststuff">
						<div id="woocommerce-coupon-data" class="postbox " >
							<h3><span class="coupon_actions"><?php echo __( 'Bulk Generate Settings ', 'COUPON_PRO_TXT_DMN' ); ?></span></h3>
							<div class="inside">
								<div class="panel-wrap">
									<div id="smart-coupon-action-panel" class="panel woocommerce_options_panel">
										<p class="form-field">
											<label><?php echo __( 'Generate Options', 'COUPON_PRO_TXT_DMN' ); ?></label>
											<input type="radio" name="smart_coupons_generate_action" value="add_to_store" id="add_to_store" checked="checked"/>&nbsp;
											<strong><?php echo __( 'Add to Databse', 'COUPON_PRO_TXT_DMN' ); ?></strong>
										</p>
										<p class="form-field">
											<label><?php echo '&nbsp;'; ?></label>
											<input type="radio" name="smart_coupons_generate_action" value="export_smart_coupon" id="export_smart_coupon" />&nbsp;
											<strong><?php echo __( 'Export to CSV', 'COUPON_PRO_TXT_DMN' ); ?></strong>
											<span class="description"><?php echo __( '(Coupon will not add but creates a .csv file, that you can import it later)', 'COUPON_PRO_TXT_DMN' ); ?></span>
										</p>
										<p class="form-field">
											<label><?php echo '&nbsp;'; ?></label>
											<input type="radio" name="smart_coupons_generate_action" value="smart_coupon_email_coupons" id="smart_coupon_email_coupons" />&nbsp;
											<strong><?php echo __( 'Email to recipients', 'COUPON_PRO_TXT_DMN' ); ?></strong>
											<span class="description"><?php __( '(Add to store and email to  coupons recipients)', 'COUPON_PRO_TXT_DMN' ); ?></span>
										</p>
										<p class="form-field">
											<label for="no_of_coupons_to_generate"><?php _e( 'Generate Number of Coupons?', 'COUPON_PRO_TXT_DMN' ); ?>&nbsp;<span title="<?php echo __( 'Required', 'COUPON_PRO_TXT_DMN' ); ?>" class="sc-required-mark">*</span></label>
											<input type="number" name="no_of_coupons_to_generate" id="no_of_coupons_to_generate" placeholder="50" class="short" min="1" required />
										</p>
										<div class="smart_coupon_visible_on_cart">
											<p class="form-field">
												<label for="bulk_generate_coupons_prefix"><?php _e( 'Coupon Prefix (Do not use space)', 'COUPON_PRO_TXT_DMN' ); ?></label>
												<input type="text" name="bulk_generate_coupons_prefix" id="bulk_generate_coupons_prefix" maxlength="10" />
											</p>
											<p class="form-field">
												<label for="bulk_generate_coupons_suffix"><?php _e( 'Coupon Suffix (Do not use space)', 'COUPON_PRO_TXT_DMN' ); ?></label>
												<input type="text" name="bulk_generate_coupons_suffix" id="bulk_generate_coupons_suffix" maxlength="10" />
											</p>
											<!-- <p class="form-field">
												<label for="no_of_letters_in_coupon"><?php _e( 'No of Letters of Coupon Title', 'COUPON_PRO_TXT_DMN' ); ?></label>
												<input type="number" name="no_of_letters_in_coupon" id="no_of_letters_in_coupon"  />
											</p> -->
										</div>
									</div>
								</div>
							</div>
						</div>
						<div id="woocommerce-coupon-data" class="postbox " >
							<?php
								if ( ! class_exists( 'WC_Meta_Box_Coupon_Data' ) ) {
									require_once WC()->plugin_path() . '/includes/admin/meta-boxes/class-wc-meta-box-coupon-data.php';
								}
							?>
							<h3><span class="coupon_actions"><?php echo __( 'Coupon Data', 'COUPON_PRO_TXT_DMN' ); ?></span></h3>
							<div class="inside">
								<?php WC_Meta_Box_Coupon_Data::output( $post ); ?>
							</div>
						</div>
					</div>
					<p class="submit"><input id="generate_and_import" name="generate_and_import" type="submit" class="button button-primary button-hero" value="<?php _e( 'Generate', 'COUPON_PRO_TXT_DMN' ); ?>" /></p>
				</form>
			</div>
			<?php
		}
		public function export_to_csv($result) {
		    if(!$result) 
		    return false;
		    //ob_end_clean();
		    header( 'Content-Type: text/csv' );
		    header( 'Content-Disposition: attachment;filename=coupons_export.csv');
		    $fp = fopen('php://output', 'w');
		    $headrow = $result[0];
		    fputcsv($fp, array_keys($headrow));
		    foreach ($result as $data) {
		        fputcsv($fp, $data);
		    }
		    fclose($fp);
		    $contLength = ob_get_length();
		    header( 'Content-Length: '.$contLength);
		}
		public function woocommerce_smart_coupon_options( ) { 
			echo '<div class="smart_coupon_visible_on_cart">';
			// for to show on cart
			woocommerce_wp_checkbox( array( 'id' => 'smart_coupon_visible_on_cart', 'label' => __( 'Show on cart/checkout?', 'COUPON_PRO_TXT_DMN' ), 'description' => __( 'When checked, this coupon will be visible on cart/checkout page', 'COUPON_PRO_TXT_DMN' ) ) );
			// for to show on cart
			woocommerce_wp_checkbox( array( 'id' => 'smart_coupon_visible_on_my_account', 'label' => __( 'Show on My Account?', 'COUPON_PRO_TXT_DMN' ), 'description' => __( 'When checked, this coupon will be visible on my account page for users', 'COUPON_PRO_TXT_DMN' ) ) );
			echo '</div>';
		}
		public function woocommerce_process_smart_coupon_meta( $post_id, $post ) {
			if ( isset( $_POST['smart_coupon_visible_on_cart'] ) ) {
				update_post_meta( $post_id, 'smart_coupon_visible_on_cart', 'yes');
			} else {
				update_post_meta( $post_id, 'smart_coupon_visible_on_cart', 'no' );
			}
			if ( isset( $_POST['smart_coupon_visible_on_my_account'] ) ) {
				update_post_meta( $post_id, 'smart_coupon_visible_on_my_account', 'yes');
			} else {
				update_post_meta( $post_id, 'smart_coupon_visible_on_my_account', 'no' );
			}
		}
	}
}
new Coupon_Pro_Generate_Bulk_Coupons();